@@ -1,17 +1,22 @@
 import pglet
-from pglet import Message
 from pglet.message import MessageButton
 
+
 def test_button():
     b1 = MessageButton("text1")
     assert isinstance(b1, pglet.Control)
     assert isinstance(b1, MessageButton)
 
+
 def test_message():
-    m = pglet.Message(value='This is message', dismiss=True, buttons=[
-    MessageButton(text='Yes, I agree', action='Yes'),
-    MessageButton(text='No, I disagree', action='No')
-])
+    m = pglet.Message(
+        value="This is message",
+        dismiss=True,
+        buttons=[
+            MessageButton(text="Yes, I agree", action="Yes"),
+            MessageButton(text="No, I disagree", action="No"),
+        ],
+    )
 
     assert isinstance(m, pglet.Control)
     assert isinstance(m, pglet.Message)
@@ -19,13 +24,18 @@ def test_message():
         'message dismiss="true" value="This is message"\n'
         '  button action="Yes" text="Yes, I agree"\n'
         '  button action="No" text="No, I disagree"'
-        ), "Test failed"
+    ), "Test failed"
+
 
 def test_message_button_with_just_text():
-    m = pglet.Message(value='This is message', dismiss=True, buttons=[
-        MessageButton(text='Yes, I agree'),
-        MessageButton(text='No, I disagree')
-        ])
+    m = pglet.Message(
+        value="This is message",
+        dismiss=True,
+        buttons=[
+            MessageButton(text="Yes, I agree"),
+            MessageButton(text="No, I disagree"),
+        ],
+    )
 
     assert isinstance(m, pglet.Control)
     assert isinstance(m, pglet.Message)
@@ -33,5 +43,4 @@ def test_message_button_with_just_text():
         'message dismiss="true" value="This is message"\n'
         '  button text="Yes, I agree"\n'
         '  button text="No, I disagree"'
-        ), "Test failed"
-
+    ), "Test failed"
